/* * This file is part of libduicontentwidgets *
 *
 * Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Otto Kopra <otto.kopra@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef MTAGEDITVIEW_H
#define MTAGEDITVIEW_H

#include <QObject>
#include <MSheet>
#include <QList>
#include <QUrl>

class MTagEditViewPrivate;

/*!
 * \class MTagEditView MTagEditView.h
 * \brief An application page for editing tags of content item(s)
 *
 * MTagEditView enables assigning or unassigning normal tags
 * and geotags. It also has links to dialogs with which user can add or
 * delete tags.
 *
 * MTagEditView inherits the MApplicationPage and is very similar in usage.
 * The calling application needs to suppy a list of tracker urls of content
 * items whose tags need to be edited, and call appear -function for
 * the MTagEditView.
 */
class MTagEditView : public MSheet
{
        Q_OBJECT

public:
    /*!
     * \brief Constructor
     * \param contentItems List of items whose tag associations are going to be edited
     * \param parent Parent of the view
     */
    MTagEditView(const QList <QUrl>& contentItems, QGraphicsItem* parent = 0);

    /*!
     * \brief Constructor which lets application to choose which color scheme is used
     * \param contentItems List of items whose tag associations are going to be edited
     * \param invertedColors if true, inverted colors are enabled. If false
     * inverted colors are disabled. Using the constructor without this parameter uses normal color scheme by default
     * \param parent Parent of the view
     */
    MTagEditView(const QList <QUrl>& contentItems, bool invertedColors, QGraphicsItem* parent = 0);

    /*!
     * \brief Destructor for MTagEditView
     */
    ~MTagEditView();

public:     // Inherited methods
    /*!
     * \brief Called by framework. Creates the tag edit view content.
     * DEPRECATED - not used by the MSheet component.
     */
    void createContent();

public slots:
    /*! re-implementation
      */
    void disappear();

protected:
    void retranslateUi();

private: // data
    Q_DECLARE_PRIVATE(MTagEditView)
    MTagEditViewPrivate* d_ptr;
    Q_DISABLE_COPY(MTagEditView)
};

#endif // MTAGEDITVIEW_H
